@@ -1,7 +1,7 @@
 /*
  * file central.h - communication interface for the server
  *
- * $Id: central.h,v 1.6 2005/04/02 14:55:12 lodott Exp $
+ * $Id: central.h,v 1.9 2006/02/10 15:07:42 fzago Exp $
  *
  * Program XBLAST
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -24,23 +24,21 @@
 #ifndef XBLAST_CENTRAL_H
 #define XBLAST_CENTRAL_H
 
-/* #include "player.h" */
-#include "network.h"
-#include "com_central.h"
-
 /* possible game stat types */
-typedef enum {
-  XBGS_Error,    /* invalid */
-  XBGS_Level,    /* level result */
-  XBGS_Complete  /* game result */
+typedef enum
+{
+	XBGS_Error,					/* invalid */
+	XBGS_Level,					/* level result */
+	XBGS_Complete				/* game result */
 } XBGameStatType;
 
 /* special pid values */
-typedef enum {
-  XBPV_Password   = -1,   /* password failed in update */
-  XBPV_Unknown    = -2,   /* unknown pid in update */
-  XBPV_Double     = -3,   /* name already registered */
-  XBPV_Incomplete = -255  /* still receiving data */
+typedef enum
+{
+	XBPV_Password = -1,			/* password failed in update */
+	XBPV_Unknown = -2,			/* unknown pid in update */
+	XBPV_Double = -3,			/* name already registered */
+	XBPV_Incomplete = -255		/* still receiving data */
 } XBPidValue;
 
 /*
@@ -49,14 +47,15 @@ typedef enum {
 
 /* start/stop */
 extern XBBool Central_StartListen (CFGGameHost *);
-extern void   Central_StopListen (void);
+extern void Central_StopListen (void);
 
 /* accept connection */
-extern void   Central_Accept (unsigned id, unsigned cnt, const char *host, unsigned port);
+extern void Central_Accept (unsigned id, unsigned cnt, const char *host, unsigned port);
 
 /* get data */
-extern void Central_GetStatistics (int *nPlayers, int *nGames, int *nGamesPlayed, int *nTotalGames, int *nLogins);
-extern int    Central_Connected();
+extern void Central_GetStatistics (int *nPlayers, int *nGames, int *nGamesPlayed, int *nTotalGames,
+								   int *nLogins);
+extern int Central_Connected (void);
 
 /* receive data */
 extern XBGameStatType Central_ReceiveGameStat (const char *line);
@@ -65,7 +64,7 @@ extern void Central_ReceiveDisconnect (unsigned id);
 extern void Central_ReceiveFinish (unsigned id);
 
 /* receive a close */
-extern void Central_ConnectionClosed(unsigned id, unsigned cnt);
+extern void Central_ConnectionClosed (unsigned id, unsigned cnt);
 
 /* queue signals */
 extern void Central_QueueDisconnect (unsigned id);
