@@ -1,7 +1,7 @@
 /*
  * cfg_control.h - keyboard and joystick configuration data
  *
- * $Id: cfg_control.h,v 1.7 2005/02/20 13:53:49 lodott Exp $
+ * $Id: cfg_control.h,v 1.9 2006/02/09 21:21:23 fzago Exp $
  *
  * Program XBLAST
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,9 +23,6 @@
 #ifndef _CFG_CONTROL_H
 #define _CFG_CONTROL_H
 
-#include "xblast.h"
-#include "event.h"
-
 /*
  * type definitions
  */
@@ -35,33 +32,35 @@
 const XBEventCode keyEventType[NUM_KEYB_CONTROLS];
 
 /* ingame controls for editing*/
-typedef struct {
-  XBAtom keyUp;
-  XBAtom keyDown;
-  XBAtom keyLeft;
-  XBAtom keyRight;
-  XBAtom keyStop;
-  XBAtom keyBomb;
-  XBAtom keySpecial;
-  XBAtom keyPause;
-  XBAtom keyAbort;
-  XBAtom keyAbortCancel;
-    /* Skywalker */
-  XBAtom keyLaola;
-  XBAtom keyLooser;
-  XBAtom keyBot;
-  XBAtom keyChatStart;
-  XBAtom keyChatSend;
-  XBAtom keyChatCancel;
-  XBAtom keyChatChangeReceiver;
-    /* */
+typedef struct
+{
+	XBAtom keyUp;
+	XBAtom keyDown;
+	XBAtom keyLeft;
+	XBAtom keyRight;
+	XBAtom keyStop;
+	XBAtom keyBomb;
+	XBAtom keySpecial;
+	XBAtom keyPause;
+	XBAtom keyAbort;
+	XBAtom keyAbortCancel;
+	/* Skywalker */
+	XBAtom keyLaola;
+	XBAtom keyLooser;
+	XBAtom keyBot;
+	XBAtom keyChatStart;
+	XBAtom keyChatSend;
+	XBAtom keyChatCancel;
+	XBAtom keyChatChangeReceiver;
+	/* */
 } CFGControlKeyboard;
 
 /* key tables for GUI */
-typedef struct {
-  const char  *keysym;
-  XBEventCode  eventCode;
-  int          eventData;
+typedef struct
+{
+	const char *keysym;
+	XBEventCode eventCode;
+	int eventData;
 } CFGKeyTable;
 
 /*
@@ -70,8 +69,8 @@ typedef struct {
 extern void LoadControlConfig (void);
 extern void SaveControlConfig (void);
 extern void FinishControlConfig (void);
-extern void StoreControlKeyboard (XBEventCode type, const CFGControlKeyboard *ctrl);
-extern XBBool RetrieveControlKeyboard (XBEventCode type, CFGControlKeyboard *ctrl);
+extern void StoreControlKeyboard (XBEventCode type, const CFGControlKeyboard * ctrl);
+extern XBBool RetrieveControlKeyboard (XBEventCode type, CFGControlKeyboard * ctrl);
 extern const CFGKeyTable *GetGameKeyPressTable (void);
 extern const CFGKeyTable *GetChatKeyTable (void);
 extern const CFGKeyTable *GetGameKeyReleaseTable (void);
