@@ -1,7 +1,7 @@
 /*
  * cfg_main.h - managing configuration files 
  *
- * $Id: cfg_main.h,v 1.4 2004/08/07 18:27:44 lodott Exp $
+ * $Id: cfg_main.h,v 1.6 2006/02/09 21:21:23 fzago Exp $
  * 
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,17 +23,16 @@
 #ifndef XBLAST_CFG_MAIN_H
 #define XBLAST_CFG_MAIN_H
 
-#include "xblast.h"
-
 /*
  * global types
  */
-typedef enum {
-  CT_Local   = 0,
-  CT_Remote,
-  CT_Demo,
-  CT_Central,
-  NUM_CT
+typedef enum
+{
+	CT_Local = 0,
+	CT_Remote,
+	CT_Demo,
+	CT_Central,
+	NUM_CT
 } CFGType;
 
 /*
