@@ -1,7 +1,7 @@
 /*
  * file com_browse.h - base communication to browse for network games
  *
- * $Id: com_browse.h,v 1.4 2004/10/21 19:28:41 lodott Exp $
+ * $Id: com_browse.h,v 1.6 2006/02/09 21:21:23 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,42 +23,43 @@
 #ifndef XBLAST_COM_BROWSE_H
 #define XBLAST_COM_BROWSE_H
 
-#include "com_base.h"
-
-#include "browse.h"
-
 /*
  * type definitions
  */
 typedef struct _xb_comm_browse XBCommBrowse;
 typedef struct _xb_browse_data XBBrowseData;
 
-typedef enum {
-  XBBE_Wait,
-  XBBE_Write,
-  XBBE_Dgram,
-  XBBE_Browse,
-  XBBE_Close,
+typedef enum
+{
+	XBBE_Wait,
+	XBBE_Write,
+	XBBE_Dgram,
+	XBBE_Browse,
+	XBBE_Close,
 } XBBrowseEvent;
 
 /* receive handler */
-typedef void (*BrowseReceiveFunc) (XBCommBrowse *, const XBBrowseTele *tele, const char *, unsigned short);
+typedef void (*BrowseReceiveFunc) (XBCommBrowse *, const XBBrowseTele * tele, const char *,
+								   unsigned short);
 /* activity handler */
 typedef XBBool (*BrowseEventFunc) (XBCommBrowse *, XBBrowseEvent);
 
-struct _xb_comm_browse {
-  XBComm             comm;
-  XBBrowseData      *sndFirst;
-  XBBrowseData      *sndLast;
-  BrowseReceiveFunc  receiveFunc;
-  BrowseEventFunc   eventFunc;
+struct _xb_comm_browse
+{
+	XBComm comm;
+	XBBrowseData *sndFirst;
+	XBBrowseData *sndLast;
+	BrowseReceiveFunc receiveFunc;
+	BrowseEventFunc eventFunc;
 };
 
 /*
  * global prototypes
  */
-extern XBComm *Browse_CommInit (XBCommBrowse *, XBCommType, XBSocket *, BrowseReceiveFunc, BrowseEventFunc, XBCommFunc);
-extern void Browse_Send (XBCommBrowse *bComm, const char *hostname, unsigned port, XBBool broadcast, const XBBrowseTeleAny *tele);
+extern XBComm *Browse_CommInit (XBCommBrowse *, XBCommType, XBSocket *, BrowseReceiveFunc,
+								BrowseEventFunc, XBCommFunc);
+extern void Browse_Send (XBCommBrowse * bComm, const char *hostname, unsigned port,
+						 XBBool broadcast, const XBBrowseTeleAny * tele);
 extern void Browse_Finish (XBCommBrowse *);
 
 #endif
