@@ -1,7 +1,7 @@
 /*
  * file com_dg_server.h - send ingame datagrams to server
  *
- * $Id: com_dg_server.h,v 1.6 2005/02/25 19:14:44 lodott Exp $
+ * $Id: com_dg_server.h,v 1.8 2006/02/09 21:21:23 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,10 +23,6 @@
 #ifndef XBLAST_COM_DG_SERVER_H
 #define XBLAST_COM_DG_SERVER_H
 
-#include "com_base.h"
-
-#include "action.h"
-
 /*
  * global prototypes
  */
@@ -40,14 +36,14 @@ extern XBBool D2S_Timeout (const XBComm *, const struct timeval *tv);
 extern XBBool D2S_Connected (const XBComm *);
 
 /* set local data */
-extern void   D2S_Reset (XBComm *comm);
-extern void   D2S_SetMaskBytes (XBComm *comm, unsigned);
+extern void D2S_Reset (XBComm * comm);
+extern void D2S_SetMaskBytes (XBComm * comm, unsigned);
 
 /* queue data */
-extern void   D2S_SendConnect (XBComm *comm);
-extern void   D2S_SendPlayerAction (XBComm *comm, int gameTime, const PlayerAction *data);
-extern void   D2S_SendFinish (XBComm *comm, int gameTime);
-extern XBBool D2S_Flush (XBComm *comm);
+extern void D2S_SendConnect (XBComm * comm);
+extern void D2S_SendPlayerAction (XBComm * comm, int gameTime, const PlayerAction * data);
+extern void D2S_SendFinish (XBComm * comm, int gameTime);
+extern XBBool D2S_Flush (XBComm * comm);
 
 #endif
 /*
