@@ -1,7 +1,7 @@
 /*
  * file com_to_central.h - handle communications with clients
  *
- * $Id: com_from_central.h,v 1.5 2005/03/15 14:09:44 lodott Exp $
+ * $Id: com_from_central.h,v 1.7 2006/02/09 21:21:23 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -24,16 +24,10 @@
 #ifndef _COM_FROM_CENTRAL_H
 #define _COM_FROM_CENTRAL_H
 
-#include "atom.h"
-#include "com_base.h"
-#include "net_socket.h"
-#include "network.h"
-#include "ini_file.h"
-
 /*
  * global prototypes
  */
-extern XBComm *C2X_CreateComm (const XBSocket *socket);
+extern XBComm *C2X_CreateComm (const XBSocket * socket);
 
 /* get data */
 extern XBBool C2X_Connected (unsigned id);
@@ -49,8 +43,3 @@ extern void C2X_QueueDisconnect (unsigned id);
 /*
  * end of file com_to_central.h
  */
-
-
-
-
-
