@@ -1,7 +1,7 @@
 /*
  * file com_newgame.h - client newGamees for local network game
  *
- * $Id: com_newgame.h,v 1.6 2004/10/30 20:11:40 lodott Exp $
+ * $Id: com_newgame.h,v 1.8 2006/02/09 21:21:23 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -24,17 +24,14 @@
 #ifndef XBLAST_COM_NEWGAME_H
 #define XBLAST_COM_NEWGAME_H
 
-#include "com.h"
-
-#include "common.h"
-#include "cfg_game.h"
-
 /*
  * global prototypes
  */
-extern XBComm *NewGame_CreateComm (const char *deviceAddress, unsigned short port, const char *broadcastAddress, const CFGGameHost *cfg, const CFGGameSetup *setup);
-extern void    NewGame_Send (XBComm *qComm, const struct timeval *tv, int num, const char *score);
-extern void    NewGame_Close (XBComm *comm, const struct timeval *tv);
+extern XBComm *NewGame_CreateComm (const char *deviceAddress, unsigned short port,
+								   const char *broadcastAddress, const CFGGameHost * cfg,
+								   const CFGGameSetup * setup);
+extern void NewGame_Send (XBComm * qComm, const struct timeval *tv, int num, const char *score);
+extern void NewGame_Close (XBComm * comm, const struct timeval *tv);
 #endif
 /*
  * end of file com_newGame.h
