@@ -1,7 +1,7 @@
 /*
  * file com_query.h - client queryes for local network game
  *
- * $Id: com_query.h,v 1.7 2005/01/21 22:22:26 lodott Exp $
+ * $Id: com_query.h,v 1.9 2006/02/09 21:21:23 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,18 +23,14 @@
 #ifndef XBLAST_COM_QUERY_H
 #define XBLAST_COM_QUERY_H
 
-#include "com.h"
-
-#include "common.h"
-#include "xblast.h"
-
 /*
  * global prototypes
  */
-extern XBComm *Query_CreateComm (unsigned id, const char *local, const char *remote, unsigned short port, XBBool broadcast);
-extern void    Query_Send (XBComm *qComm, const struct timeval *tv);
-extern void    Query_NewGame (XBComm *qComm, const struct timeval *tv);
-extern XBBool  Query_isDeleted (XBComm *qComm);
+extern XBComm *Query_CreateComm (unsigned id, const char *local, const char *remote,
+								 unsigned short port, XBBool broadcast);
+extern void Query_Send (XBComm * qComm, const struct timeval *tv);
+extern void Query_NewGame (XBComm * qComm, const struct timeval *tv);
+extern XBBool Query_isDeleted (XBComm * qComm);
 
 #endif
 /*
