@@ -1,7 +1,7 @@
 /*
  * file com_reply.h - server answers to broadcasts by clients
  *
- * $Id: com_reply.h,v 1.3 2004/05/14 10:00:33 alfie Exp $
+ * $Id: com_reply.h,v 1.5 2006/02/09 21:21:23 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,9 +23,6 @@
 #ifndef XBLAST_COM_REPLY_H
 #define XBLAST_COM_REPLY_H
 
-#include "com.h"
-#include "cfg_game.h"
-
 /*
  * type definitions
  */
@@ -33,7 +30,8 @@
 /*
  * global prototypes
  */
-extern XBComm* Reply_CreateComm (unsigned short replyPort, const CFGGameHost *cfg, const CFGGameSetup *);
+extern XBComm *Reply_CreateComm (unsigned short replyPort, const CFGGameHost * cfg,
+								 const CFGGameSetup *);
 
 #endif
 /*
