@@ -1,7 +1,7 @@
 /*
  * file com_to_central.h - handle communications with centrals
  *
- * $Id: com_to_central.h,v 1.4 2004/11/11 14:57:08 lodott Exp $
+ * $Id: com_to_central.h,v 1.6 2006/02/09 21:21:23 fzago Exp $
  *
  * Program XBLAST
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -24,25 +24,19 @@
 #ifndef _COM_TO_CENTRAL_H
 #define _COM_TO_CENTRAL_H
 
-#include "atom.h"
-#include "com_base.h"
-#include "net_socket.h"
-#include "network.h"
-#include "ini_file.h"
-#include "cfg_xblast.h"
-
 /*
  * event codes
  */
-typedef enum {
-  XBE2C_IORead,          /* read error occurred */
-  XBE2C_IOWrite,         /* write error occurred */
-  XBE2C_UnexpectedEOF,   /* eof received */
-  XBE2C_StreamWaiting,   /* all queued data sent on stream */
-  XBE2C_StreamBusy,      /* queued data on stream partially sent */
-  XBE2C_StreamClosed,    /* stream has been removed */
-  XBE2C_InvalidCot,      /* invalid telegram cot */
-  XBE2C_InvalidID,       /* invalid telegram id */
+typedef enum
+{
+	XBE2C_IORead,				/* read error occurred */
+	XBE2C_IOWrite,				/* write error occurred */
+	XBE2C_UnexpectedEOF,		/* eof received */
+	XBE2C_StreamWaiting,		/* all queued data sent on stream */
+	XBE2C_StreamBusy,			/* queued data on stream partially sent */
+	XBE2C_StreamClosed,			/* stream has been removed */
+	XBE2C_InvalidCot,			/* invalid telegram cot */
+	XBE2C_InvalidID,			/* invalid telegram id */
 } XBEventToCentral;
 
 /*
@@ -53,12 +47,12 @@ extern XBComm *X2C_CreateComm (const CFGCentralSetup *);
 extern const char *X2C_CentralName (XBComm *);
 extern const char *X2C_LocalName (XBComm *);
 
-extern void X2C_Disconnect (XBComm *comm);
-extern void X2C_SendDisconnect (XBComm *comm);
+extern void X2C_Disconnect (XBComm * comm);
+extern void X2C_SendDisconnect (XBComm * comm);
 
-extern void X2C_QueryPlayerConfig (XBComm *comm);
-extern void X2C_SendPlayerConfig (XBComm *comm, XBAtom);
-extern void X2C_SendGameStat (XBComm *comm, int numPlayers, int *PID, int *Score);
+extern void X2C_QueryPlayerConfig (XBComm * comm);
+extern void X2C_SendPlayerConfig (XBComm * comm, XBAtom);
+extern void X2C_SendGameStat (XBComm * comm, int numPlayers, int *PID, int *Score);
 
 #endif
 /*
