@@ -1,7 +1,7 @@
 /*
  * file demo.h - recording and playback of xblast games
  *
- * $Id: demo.h,v 1.5 2005/03/12 14:12:31 lodott Exp $
+ * $Id: demo.h,v 1.7 2006/02/09 21:21:23 fzago Exp $
  *
  * Program XBLAST
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -24,9 +24,6 @@
 #ifndef _DEMO_H
 #define _DEMO_H
 
-#include "action.h"
-#include "cfg_game.h"
-
 /*
  * type definitions
  */
@@ -36,12 +33,12 @@
  */
 
 /* initialize recording */
-extern void DemoInitGame (CFGType cfgType, const CFGGame *cfgGame);
+extern void DemoInitGame (CFGType cfgType, const CFGGame * cfgGame);
 extern void DemoInitLevel (XBAtom level);
 /* game recording */
-extern void DemoRecordFrame (int gameTime, const PlayerAction *pa);
+extern void DemoRecordFrame (int gameTime, const PlayerAction * pa);
 /* finish recording */
-extern void DemoFinishLevel (int gameTime,int winner, const char *type);
+extern void DemoFinishLevel (int gameTime, int winner, const char *type);
 extern void DemoFinishGame (void);
 /* get game config for playback */
 extern XBBool DemoPlaybackConfig (CFGGame *);
@@ -50,7 +47,7 @@ extern XBAtom DemoPlaybackLevel (void);
 /* load actions for playback */
 extern XBBool DemoPlaybackStart (void);
 /* get action for playback */
-extern XBBool DemoPlaybackFrame (int gameTime, PlayerAction *pa);
+extern XBBool DemoPlaybackFrame (int gameTime, PlayerAction * pa);
 
 #endif
 /*
