@@ -1,7 +1,7 @@
 /*
  * file gui.h - interface for system dependent graphics engine
  *
- * $Id: gui.h,v 1.7 2005/02/25 22:39:34 lodott Exp $
+ * $Id: gui.h,v 1.10 2006/02/24 21:57:55 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,9 +23,6 @@
 #ifndef XBLAST_GUI_H
 #define XBLAST_GUI_H
 
-#include "sprite.h"
-#include "cfg_player.h"
-
 /*
  * constants
  */
@@ -55,19 +52,21 @@
 /*
  * types
  */
-typedef enum {
-  KB_NONE,   /* no keyboard events are generated */
-  KB_CHAT,   /* uses chat keymapping */
-  KB_MENU,   /* uses XBlast chat+menu keymapping */
-  KB_XBLAST, /* uses XBlast chat+game keymapping */
-  KB_KEYSYM, /* return string with keysymbol name (for text editor) */
-  KB_ASCII   /* return ascii-value or control key (for keyboard config ) */
+typedef enum
+{
+	KB_NONE,					/* no keyboard events are generated */
+	KB_CHAT,					/* uses chat keymapping */
+	KB_MENU,					/* uses XBlast chat+menu keymapping */
+	KB_XBLAST,					/* uses XBlast chat+game keymapping */
+	KB_KEYSYM,					/* return string with keysymbol name (for text editor) */
+	KB_ASCII					/* return ascii-value or control key (for keyboard config ) */
 } XBKeyboardMode;
 
-typedef enum {
-  XBFM_IN,        /* blend in current pixmap */
-  XBFM_BLACK_OUT, /* fade out current image to black */
-  XBFM_WHITE_OUT  /* fade out current image to white */
+typedef enum
+{
+	XBFM_IN,					/* blend in current pixmap */
+	XBFM_BLACK_OUT,				/* fade out current image to black */
+	XBFM_WHITE_OUT				/* fade out current image to white */
 } XBFadeMode;
 
 typedef void (*XBPollFunction) (const struct timeval *);
@@ -86,8 +85,8 @@ extern void GUI_UpdateKeyTables (void);
 extern void GUI_SetTimer (long msec, XBBool periodic);
 extern void GUI_SetKeyboardMode (XBKeyboardMode _mode);
 extern void GUI_SetMouseMode (XBBool _enable);
-extern XBEventCode GUI_WaitEvent (XBEventData *data);
-extern XBEventCode GUI_PeekEvent (XBEventData *data);
+extern XBEventCode GUI_WaitEvent (XBEventData * data);
+extern XBEventCode GUI_PeekEvent (XBEventData * data);
 extern void GUI_SendEventValue (XBEventCode code, int value);
 extern void GUI_SendEventPointer (XBEventCode code, void *pointer);
 extern void GUI_Sync (void);
@@ -95,6 +94,8 @@ extern void GUI_Bell (void);
 extern int GUI_NumJoysticks (void);
 extern void GUI_AddPollFunction (XBPollFunction func);
 extern void GUI_SubtractPollFunction (XBPollFunction func);
+extern void GUI_ShowCursor(XBBool enable);
+
 /* pixmap */
 extern void GUI_AddMazeRectangle (int x, int y);
 extern void GUI_AddStatRectangle (int x, int y);
@@ -106,18 +107,18 @@ extern void GUI_ClearPixmap (void);
 extern void GUI_InitFade (XBFadeMode mode, int maxLines);
 extern XBBool GUI_DoFade (void);
 /* sprite */
-extern XBBool GUI_LoadPlayerSprite (int player, int anime, const CFGPlayerGraphics *config);
+extern XBBool GUI_LoadPlayerSprite (int player, int anime, const CFGPlayerGraphics * config);
 extern void GUI_LoadIconSprite (int index, XBColor color);
 extern void GUI_DrawExplosionSprite (int x, int y, int block);
-extern void GUI_DrawPlayerSprite (const Sprite *spl);
-extern void GUI_DrawBombSprite (const Sprite *spl);
-extern void GUI_DrawIconSprite (const Sprite *spl);
-extern void GUI_DrawTextSprite (const Sprite *spl);
+extern void GUI_DrawPlayerSprite (const Sprite * spl);
+extern void GUI_DrawBombSprite (const Sprite * spl);
+extern void GUI_DrawIconSprite (const Sprite * spl);
+extern void GUI_DrawTextSprite (const Sprite * spl);
 /* text */
-extern void GUI_DrawSimpleTextbox (const char *text, unsigned flags, const BMRectangle *rect);
-extern void GUI_DrawTextbox (const char *text, unsigned flags, const BMRectangle *rect);
-extern void GUI_DrawPolygon (int x, int y, int w, int h, int lw, const BMPoint *points, 
-			     int npoints, XBBool black_white);
+extern void GUI_DrawSimpleTextbox (const char *text, unsigned flags, const BMRectangle * rect);
+extern void GUI_DrawTextbox (const char *text, unsigned flags, const BMRectangle * rect);
+extern void GUI_DrawPolygon (int x, int y, int w, int h, int lw, const BMPoint * points,
+							 int npoints, XBBool black_white);
 /* tile */
 extern void GUI_DrawBlock (int x, int y, int block);
 extern void GUI_DrawExplosion (int x, int y, int block);
@@ -127,7 +128,7 @@ extern void GUI_LoadBlockRgb (int id, const char *name);
 extern void GUI_LoadBlockCch (int id, const char *name, XBColor fg, XBColor bg, XBColor add);
 extern void GUI_FreeBlock (int block);
 extern void GUI_FreeExplosionBlocks (void);
-extern void GUI_LoadPlayerScoreTiles (int player, const CFGPlayerGraphics *config);
+extern void GUI_LoadPlayerScoreTiles (int player, const CFGPlayerGraphics * config);
 extern void GUI_DrawScoreBlock (int x, int y, int block);
 extern void GUI_DrawTimeLed (int x, int block);
 /* atoms */
