@@ -1,7 +1,7 @@
 /*
  * file menu.h -
  *
- * $Id: menu.h,v 1.3 2004/05/14 10:00:35 alfie Exp $
+ * $Id: menu.h,v 1.4 2006/02/09 21:21:24 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -24,10 +24,6 @@
 #ifndef _MENU_H
 #define _MENU_H
 
-#include "event.h"
-#include "cfg_player.h"
-#include "cfg_game.h"
-
 /*
  * global prototypes
  */
