@@ -1,7 +1,7 @@
 /*
  * file menu_game.h - menus for setting up game parameters
  *
- * $Id: menu_game.h,v 1.3 2004/05/14 10:00:35 alfie Exp $
+ * $Id: menu_game.h,v 1.5 2006/02/09 21:21:24 fzago Exp $
  * 
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,9 +23,6 @@
 #ifndef _MENU_GAME_H
 #define _MENU_GAME_H
 
-#include "xblast.h"
-#include "cfg_game.h"
-
 /*
  * prototypes
  */
@@ -33,9 +30,9 @@ extern XBBool CreateLocalGameMenu (void *par);
 extern XBBool CreateStartNetGameMenu (void *par);
 extern XBBool CreateJoinNetGameMenu (void *par);
 
-extern void setAutoCentral(XBBool set); // XBCC
-extern XBBool CreateCentralGameMenu (void *par); // XBCC
-extern XBBool CreateCentralJoinMenu (void *par); // XBCC
+extern void setAutoCentral (XBBool set);	// XBCC
+extern XBBool CreateCentralGameMenu (void *par);	// XBCC
+extern XBBool CreateCentralJoinMenu (void *par);	// XBCC
 
 extern XBPlayerHost GetHostType (void);
 extern void SetHostType (XBPlayerHost);
