@@ -1,7 +1,7 @@
 /*
  * file menu_level.c - level selection menu
  *
- * $Id: menu_level.h,v 1.4 2005/03/07 16:22:52 lodott Exp $
+ * $Id: menu_level.h,v 1.7 2006/02/10 15:07:42 fzago Exp $
  *
  * Program XBLAST
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,25 +23,24 @@
 #ifndef XBLAST_MENU_LEVEL_H
 #define XBLAST_MENU_LEVEL_H
 
-#include "mi_tool.h"
-
 /*
  * type defintions
  */
-typedef struct {
-  const char *textAbort;
-  MIC_button  funcAbort;
-  void       *parAbort;
-  const char *textDefault;
-  MIC_button  funcDefault;
-  void       *parDefault;
+typedef struct
+{
+	const char *textAbort;
+	MIC_button funcAbort;
+	void *parAbort;
+	const char *textDefault;
+	MIC_button funcDefault;
+	void *parDefault;
 } XBMenuLevelPar;
 
 /*
  * global prototypes
  */
 extern XBBool CreateLevelMenu (void *par);
-extern void   FinishLevelSelection ();
+extern void FinishLevelSelection (void);
 
 #endif
 /*
