@@ -1,7 +1,7 @@
 /*
  * file mi_button.h - 
  *
- * $Id: mi_button.h,v 1.3 2004/05/14 10:00:35 alfie Exp $
+ * $Id: mi_button.h,v 1.6 2006/02/10 15:07:42 fzago Exp $
  * 
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,15 +23,14 @@
 #ifndef _MI_BUTTON_H
 #define _MI_BUTTON_H
 
-#include "mi_base.h"
-#include "sprite.h"
-
-extern XBMenuItem * MenuCreateHButton (int x, int y, int w, const char *text, MIC_button func, void *funcData);
-extern XBMenuItem * MenuCreateVButton (int x, int y, int h, const char *text, MIC_button func, void *funcData);
-extern void MenuSetButtonIcon (XBMenuItem *item, IconSpriteAnimation anime);
-extern void MenuDeleteButton (XBMenuItem *item);
-extern void MenuActivateButton (XBMenuItem *ptr, XBBool flag);
-extern XBBool MenuExecButton ();
+extern XBMenuItem *MenuCreateHButton (int x, int y, int w, const char *text, MIC_button func,
+									  void *funcData);
+extern XBMenuItem *MenuCreateVButton (int x, int y, int h, const char *text, MIC_button func,
+									  void *funcData);
+extern void MenuSetButtonIcon (XBMenuItem * item, IconSpriteAnimation anime);
+extern void MenuDeleteButton (XBMenuItem * item);
+extern void MenuActivateButton (XBMenuItem * ptr, XBBool flag);
+extern XBBool MenuExecButton (void);
 extern void MenuButtonSetNextExec (MIC_button func, void *data);
 #endif
 /*
