@@ -1,7 +1,7 @@
 /*
  * file mi_color.h -
  *
- * $Id: mi_color.h,v 1.3 2004/05/14 10:00:35 alfie Exp $
+ * $Id: mi_color.h,v 1.5 2006/02/09 21:21:24 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,10 +23,9 @@
 #ifndef _MI_COLOR_H
 #define _MI_COLOR_H
 
-#include "mi_base.h"
-
-extern XBMenuItem *MenuCreateColor  (int x, int y, int w, const char *text, XBColor *color, XBRgbValue *pRgb);
-extern void MenuDeleteColor (XBMenuItem *item);
+extern XBMenuItem *MenuCreateColor (int x, int y, int w, const char *text, XBColor * color,
+									XBRgbValue * pRgb);
+extern void MenuDeleteColor (XBMenuItem * item);
 
 #endif
 /*
