@@ -1,7 +1,7 @@
 /*
  * file mi_combo.h -
  *
- * $Id: mi_combo.h,v 1.3 2004/05/14 10:00:35 alfie Exp $
+ * $Id: mi_combo.h,v 1.5 2006/02/09 21:21:24 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,11 +23,10 @@
 #ifndef _MI_COMBO_H
 #define _MI_COMBO_H
 
-#include "mi_base.h"
-
-extern XBMenuItem *MenuCreateCombo (int x, int y, int w_text, const char *text, int w, 
-				    int *value, void **data, XBAtom *atom, XBComboEntryList *table);
-extern void MenuDeleteCombo (XBMenuItem *item);
+extern XBMenuItem *MenuCreateCombo (int x, int y, int w_text, const char *text, int w,
+									int *value, void **data, XBAtom * atom,
+									XBComboEntryList * table);
+extern void MenuDeleteCombo (XBMenuItem * item);
 
 #endif
 /*
