@@ -1,7 +1,7 @@
 /*
  * file mi_int.h - Mmenu item for editing integers
  *
- * $Id: mi_int.h,v 1.3 2004/05/14 10:00:35 alfie Exp $
+ * $Id: mi_int.h,v 1.5 2006/02/09 21:21:24 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,15 +23,11 @@
 #ifndef _MI_INT_H
 #define _MI_INT_H
 
-#include "mi_base.h"
-/*
- * type definitions
- */
-
 /*
  * global prototypes
  */
-extern XBMenuItem *MenuCreateInteger (int x, int y, int w_text, const char *text, int w, int *pValue, int min, int max);
+extern XBMenuItem *MenuCreateInteger (int x, int y, int w_text, const char *text, int w,
+									  int *pValue, int min, int max);
 extern void MenuDeleteInteger (XBMenuItem *);
 
 #endif
