@@ -1,7 +1,7 @@
 /*
  * file mi_player.h -
  *
- * $Id: mi_player.h,v 1.4 2005/02/24 17:54:56 iskywalker Exp $
+ * $Id: mi_player.h,v 1.6 2006/02/09 21:21:24 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,17 +23,16 @@
 #ifndef _MI_PLAYER_H
 #define _MI_PLAYER_H
 
-#include "mi_base.h"
-#include "sprite.h"
-#include "cfg_player.h"
-
 /*
  * global prototypes
  */
-extern XBMenuItem *MenuCreatePlayer (int x, int y, int w, int sprite, const CFGPlayerGraphics **cfg,
-				     int nAnime, BMSpriteAnimation *anime);extern XBMenuItem *MenuCreateConfigPlayer (int x, int y, int w, int sprite, const CFGPlayerGraphics **cfg,
-				     int nAnime, BMSpriteAnimation *anime, XBRgbValue *pRgb);
-extern void MenuDeletePlayer (XBMenuItem *item);
+extern XBMenuItem *MenuCreatePlayer (int x, int y, int w, int sprite,
+									 const CFGPlayerGraphics ** cfg, int nAnime,
+									 BMSpriteAnimation * anime);
+extern XBMenuItem *MenuCreateConfigPlayer (int x, int y, int w, int sprite,
+										   const CFGPlayerGraphics ** cfg, int nAnime,
+										   BMSpriteAnimation * anime, XBRgbValue * pRgb);
+extern void MenuDeletePlayer (XBMenuItem * item);
 
 #endif
 /*
