@@ -1,7 +1,7 @@
 /*
  * file SDL_image.h -
  *
- * $Id: sdl_image.h,v 1.3 2004/09/13 22:33:45 tenderflake Exp $
+ * $Id: sdl_image.h,v 1.6 2006/02/09 21:21:24 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -20,23 +20,16 @@
  * with this program; if not, write to the Free Software Foundation, Inc.
  * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#ifndef _SDL_IMAGE_H
-#define _SDL_IMAGE_H
-
-#include "sdl_common.h"
-#include <SDL/SDL.h>
-
-#include "xblast.h"
-#include "color.h"
+#ifndef XBLAST_SDL_IMAGE_H
+#define XBLAST_SDL_IMAGE_H
 
 extern XBBool InitImages (void);
 extern void FinishImages (void);
 extern SDL_Surface *ReadPbmBitmap (const char *path, const char *filename);
 extern SDL_Surface *ReadRgbPixmap (const char *path, const char *filename);
-extern SDL_Surface *ReadCchPixmap (const char *path, const char *filename, XBColor fg, XBColor bg, XBColor add);
-extern SDL_Surface *ReadEpmPixmap (const char *path, const char *filename, int n_colors, const XBColor *color);
+extern SDL_Surface *ReadCchPixmap (const char *path, const char *filename, XBColor fg, XBColor bg,
+								   XBColor add);
+extern SDL_Surface *ReadEpmPixmap (const char *path, const char *filename, int n_colors,
+								   const XBColor * color);
 
 #endif
-/*
- *
- */
