@@ -1,7 +1,7 @@
 /*
  * file snd.h - sound library for xblast
  *
- * $Id: snd.h,v 1.6 2005/03/08 09:54:56 lodott Exp $
+ * $Id: snd.h,v 1.10 2006/06/12 11:06:36 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -24,72 +24,71 @@
 #ifndef XBLAST_SND_H
 #define XBLAST_SND_H
 
-#include "cfg_xblast.h"
-
 /*
  * type definitions
  */
 
 /* sound samples */
-typedef enum {
-  SND_BAD,
-  SND_DROP,
-  SND_NEWBOMB,
-  SND_NEWKICK,
-  SND_NEWPUMP,
-  SND_NEWRC,
-  SND_MOREFIRE,
-  SND_DEAD,
-  SND_EXPL,
-  SND_KICK,
-  SND_PUMP,
-  SND_OUCH,
-  SND_INTRO,
-  SND_APPL,
-  SND_APPL2,
-  SND_BUTT,
-  SND_SHOOT,
-  SND_INVIS,
-  SND_INVINC,
-  SND_NEWTELE,
-  SND_TELE,
-  SND_INJ,
-  SND_MINIBOMB,
-  SND_WON,
-  SND_HAUNT,
-  SND_SPIRAL,
-  SND_SPBOMB,
-  SND_SLIDE,
-  SND_FINALE,
-  SND_WARN,
-  SND_STUN,
-  SND_WHIRL,
-  SND_COMPOUND,
-  SND_TELE1,
-  SND_TELE2,
-  SND_HOLY,
-  SND_ENCLOAK,
-  SND_DECLOAK,
-  SND_FAST,
-  SND_SLOW,
-  SND_SLAY,
-  SND_LIFE,
-  SND_NEWCLOAK,
-  SND_BOMBMORPH,
-  SND_STEP1,
-  SND_STEP2,
-  SND_STEP3,
-  SND_STEP4,
-  SND_STEP5,
-  SND_STEP6,
-  SND_SNG1,
-  SND_SNG2,
-  SND_SNG3,
-  SND_SNG4,
-  SND_SNG5,
-  SND_SNG6,
+typedef enum
+{
+	SND_BAD,
+	SND_DROP,
+	SND_NEWBOMB,
+	SND_NEWKICK,
+	SND_NEWPUMP,
+	SND_NEWRC,
+	SND_MOREFIRE,
+	SND_DEAD,
+	SND_EXPL,
+	SND_KICK,
+	SND_PUMP,
+	SND_OUCH,
+	SND_INTRO,
+	SND_APPL,
+	SND_APPL2,
+	SND_BUTT,
+	SND_SHOOT,
+	SND_INVIS,
+	SND_INVINC,
+	SND_NEWTELE,
+	SND_TELE,
+	SND_INJ,
+	SND_MINIBOMB,
+	SND_WON,
+	SND_HAUNT,
+	SND_SPIRAL,
+	SND_SPBOMB,
+	SND_SLIDE,
+	SND_FINALE,
+	SND_WARN,
+	SND_STUN,
+	SND_WHIRL,
+	SND_COMPOUND,
+	SND_TELE1,
+	SND_TELE2,
+	SND_HOLY,
+	SND_ENCLOAK,
+	SND_DECLOAK,
+	SND_FAST,
+	SND_SLOW,
+	SND_SLAY,
+	SND_LIFE,
+	SND_NEWCLOAK,
+	SND_BOMBMORPH,
+	SND_STEP1,
+	SND_STEP2,
+	SND_STEP3,
+	SND_STEP4,
+	SND_STEP5,
+	SND_STEP6,
+	SND_SNG1,
+	SND_SNG2,
+	SND_SNG3,
+	SND_SNG4,
+	SND_SNG5,
+	SND_SNG6,
   /*---*/
-  SND_MAX
+	SND_MAX
 } SND_Id;
 
 /* 
@@ -99,6 +98,9 @@ typedef enum {
 #define MAX_SOUND_POSITION     15
 #define SOUND_MIDDLE_POSITION  7
 
+/*
+ * Special id to stop all sounds */
+#define STOP_ALL_SOUNDS     0
 
 /* 
  * function protoypes 
@@ -110,7 +112,7 @@ extern XBBool SND_Load (SND_Id id);
 extern XBBool SND_Unload (SND_Id id);
 extern void SND_Flush (void);
 extern void SND_Finish (void);
-extern void SND_Beep ();
+extern void SND_Beep (void);
 
 #endif
 
