@@ -1,7 +1,7 @@
 /*
  * file status.h
  *
- * $Id: status.h,v 1.4 2004/10/19 17:59:19 iskywalker Exp $
+ * $Id: status.h,v 1.7 2006/02/10 15:07:35 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,18 +23,15 @@
 #ifndef XBLAST_STATUS_H
 #define XBLAST_STATUS_H
 
-#include "player.h"
-
 extern void ClearStatusBar (int tile1, int tile2);
 extern void InitStatusBar (int numPlayer);
-extern void ResetStatusBar (const BMPlayer *ps,  const char *msg, XBBool flag);
-extern void UpdateStatusBar (const BMPlayer *ps, int g_time);
+extern void ResetStatusBar (const BMPlayer * ps, const char *msg, XBBool flag);
+extern void UpdateStatusBar (const BMPlayer * ps, int g_time);
 extern void SetMessage (const char *msg, XBBool perm);
 extern void ResetMessage (void);
-extern void SetGet (char *msg, int perm);
+extern void SetGet (const char *msg, int perm);
 extern void SetChat (char *msg, int perm);
 
-
 #endif
 /*
  * end of file status.c
