@@ -1,7 +1,7 @@
 /*
  * file x11_socket.h - true bsd sockets for xblast
  *
- * $Id: x11_socket.h,v 1.3 2004/05/14 10:00:36 alfie Exp $
+ * $Id: x11_socket.h,v 1.5 2006/02/09 21:21:25 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,18 +23,14 @@
 #ifndef XBLAST_X11_SOCKET_H
 #define XBLAST_X11_SOCKET_H
 
-#include "xblast.h"
-
-#include "gui.h"
-
 /*
  * global prototypes
  */
-extern void   RegisterDisplay  (int fd);
-extern XBBool SelectSockets    (XBKeyboardMode kbMode, struct timeval *timeout);
-extern void   RegisterJoystick (int fd);
-extern void   RegisterSound    (int fd);
-extern void   UnregisterSound  (int fd);
+extern void RegisterDisplay (int fd);
+extern XBBool SelectSockets (XBKeyboardMode kbMode, struct timeval *timeout);
+extern void RegisterJoystick (int fd);
+extern void RegisterSound (int fd);
+extern void UnregisterSound (int fd);
 
 #endif
 /*
