@@ -1,7 +1,7 @@
 /*
  * file x11c_image.h -
  *
- * $Id: x11c_image.h,v 1.3 2004/05/14 10:00:36 alfie Exp $
+ * $Id: x11c_image.h,v 1.5 2006/02/09 21:21:25 fzago Exp $
  *
  * Program XBLAST 
  * (C) by Oliver Vogel (e-mail: m.vogel@ndh.net)
@@ -23,17 +23,16 @@
 #ifndef _X11_COLOR_IMAGE_H
 #define _X11_COLOR_IMAGE_H
 
-#include "x11_common.h"
-#include "color.h"
-
 /*
  * global prototypes
  */
 extern XBBool InitImage (int visual_class);
 extern Pixmap ReadPbmBitmap (const char *path, const char *filename);
 extern Pixmap ReadRgbPixmap (const char *path, const char *filename);
-extern Pixmap ReadCchPixmap (const char *path, const char *filename, XBColor fg, XBColor bg, XBColor add);
-extern Pixmap ReadEpmPixmap (const char *path, const char *filename, int n_colors, const XBColor *color);
+extern Pixmap ReadCchPixmap (const char *path, const char *filename, XBColor fg, XBColor bg,
+							 XBColor add);
+extern Pixmap ReadEpmPixmap (const char *path, const char *filename, int n_colors,
+							 const XBColor * color);
 
 #endif
 /*
